@@ -8,6 +8,8 @@ public class      PerlTextListener
     String sender;
     String callbacks;
 
+    public PerlTextListener() throws InlineJavaException { }
+
     public PerlTextListener(String sender, String callbacks)
         throws InlineJavaException
     {
@@ -15,11 +17,14 @@ public class      PerlTextListener
         this.callbacks = callbacks;
     }
 
-    public void textValueChanged(java.awt.event.TextEvent event) {
+    public void setSender   (String sender)    { this.sender    = sender; }
+    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }
+
+    public void textValueChanged(java.awt.event.TextEvent event)  {
         try {
             CallPerl(
-                "Java::Swing::TextListener",
-                "_TextListener",
+                "Java::Swing",
+                "_Listener",
                 new Object[] {sender, callbacks, "textValueChanged", event}
             );
         }
