@@ -8,6 +8,8 @@ public class      PerlUndoableEditListener
     String sender;
     String callbacks;
 
+    public PerlUndoableEditListener() throws InlineJavaException { }
+
     public PerlUndoableEditListener(String sender, String callbacks)
         throws InlineJavaException
     {
@@ -15,11 +17,14 @@ public class      PerlUndoableEditListener
         this.callbacks = callbacks;
     }
 
+    public void setSender   (String sender)    { this.sender    = sender; }
+    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }
+
     public void undoableEditHappened(javax.swing.event.UndoableEditEvent event)  {
         try {
             CallPerl(
-                "Java::Swing::UndoableEditListener",
-                "_UndoableEditListener",
+                "Java::Swing",
+                "_Listener",
                 new Object[] {sender, callbacks, "undoableEditHappened", event}
             );
         }
